pub struct ClosureRef<State, Input, Output> { /* private fields */ }Expand description
A Closure does not own its state, and only refers to the state when called.
Correspond to unnamable closures like:
ⓘ
|...| { /* only refers captured variables */ }Examples:
// state refered as reference in body, but moved to the closure
let add_ten:ClosureRef<i32,(i32,),i32>
= closure!(ref state=10 => move |i| i+*state);
assert_eq!(add_ten.stable_call((1,)),11);
let mut offset:ClosureRef<Point,(i32,i32),Point>
= closure!(ref state=Point::new(10,20) => move |a,b| Point::new(state.x+a,state.y+b));
let p = offset.stable_call_mut((1,2));
assert_eq!(p.x,11);
assert_eq!(p.y,22);Implementations
Sourceimpl<State, Input, Output> ClosureRef<State, Input, Output>
impl<State, Input, Output> ClosureRef<State, Input, Output>